###################################################################################################################################################
# Copyright 2015 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###################################################################################################################################################

from accpac import *

# -------------------------------------------------
# Written by: Orchid Systems
# -------------------------------------------------
# This script validates the length of A/P vendor's address fields as this can cause problems with some EFT Processing bank export formats.
# Also validates the Remit-To address selected as part of the vendor's EFT setup.
# If no Remit-To was chosen, then the script won't validate it.
# -------------------------------------------------

# onOpen is called when the view is opened.
# Return Continue to enable the macro.
# Return 0 to disable the macro.
# If you return anything else then the view will not load.

def onOpen():
	if rotoID != "EL0006":
		return 0 # don't do anything since the view is not ELVEND.
	return Continue

def onBeforeUpdate():
	return ValidateAddress()

def onBeforeInsert():
	return ValidateAddress()

def ValidateAddress():

	#--- default return condition.
	errFlag = Continue

	#--- Read AP Vendor Record
	apvend = openView("AP0015", 1)	# AP VENDORS
	apvend.recordClear()
	apvend.browse("VENDORID=\"" + str(me.get("VENDORID")) + "\"", 1)

	#--- res will be zero on success.
	res = apvend.fetch()
	if res == 0:
		# Vendor record was found.
		if (',') in ReplaceFields(apvend, "{TEXTSTRE1}"):
			error("Commas are not allowed in Vendor Address fields. Comma found in address line 1.")
			errFlag = 1
		if (',') in ReplaceFields(apvend, "{TEXTSTRE2}"):
			error("Commas are not allowed in Vendor Address fields. Comma found in address line 2.")
			errFlag = 1
		if (',') in ReplaceFields(apvend, "{TEXTSTRE3}"):
			error("Commas are not allowed in Vendor Address fields. Comma found in address line 3.")
			errFlag = 1
		if (',') in ReplaceFields(apvend, "{TEXTSTRE4}"):
			error("Commas are not allowed in Vendor Address fields. Comma found in address line 4.")
			errFlag = 1
		

	apvend.close()
			
	#--- Validate Remit-To Addresses ------------------
	remitto = str(me.get("REMIT"))

	if remitto == "":
		return errFlag	# Exit if there is no remit-to address code specified in the EFT Vendor setup record.
		
	apremitto = openView("AP0018", 1)	#AP VENDOR REMIT-TO ADDRESSES.

	sFilter = "IDVEND = \"" + str(me.get("VENDORID")) + "\" AND IDVENDRMIT = \"" + remitto + "\""

	apremitto.recordClear()
	apremitto.browse(sFilter, 1)
	if (apremitto.fetch() == 0):
		# check each remit-to address.

		if (',') in ReplaceFields(apremitto, "{TEXTSTRE1}"):
			error("Commas are not allowed in Vendor Remit-to Address fields. Comma found in address line 1.")
			errFlag = 1
		if (',') in ReplaceFields(apremitto, "{TEXTSTRE2}"):
			error("Commas are not allowed in Vendor Remit-to Address fields. Comma found in address line 2.")
			errFlag = 1
		if (',') in ReplaceFields(apremitto, "{TEXTSTRE3}"):
			error("Commas are not allowed in Vendor Remit-to Address fields. Comma found in address line 3.")
			errFlag = 1
		if (',') in ReplaceFields(apremitto, "{TEXTSTRE4}"):
			error("Commas are not allowed in Vendor Remit-to Address fields. Comma found in address line 4.")
			errFlag = 1

	apremitto.close()

	return errFlag
